@@ -295,14 +295,6 @@ class Common(object):
 
         return feature_names
 
-    @staticmethod
-    def get_current_run_id():
-        try:
-            with open(get_or_create_run_directory() + 'run_info.json') as json_file:
-                return json.load(json_file)['run_name']
-        except FileNotFoundError or KeyError:
-            return ''
-
     def set_current_notebook(self):
         self.notebook_info = get_current_notebook()
 
