@@ -1,8 +1,6 @@
 import logging
 import re
 import os
-from slack_sdk import WebClient
-from slack_sdk.errors import SlackApiError
 
 logging.basicConfig(level=logging.DEBUG)
 
@@ -12,25 +10,6 @@ class AbcNotifier:
         pass
 
 
-class SlackApp(AbcNotifier):
-    def __init__(self, token, channel_id):
-        self.token = token
-        self.channel_id = channel_id
-        self.client = WebClient(token=self.token)
-
-    def send_message(self, message='Job is done.'):
-        try:
-            response = self.client.chat_postMessage(
-                channel=self.channel_id,
-                text=message
-            )
-        except SlackApiError as e:
-            assert e.response["error"]
-
-    def completed_message(self, **kwargs):
-        self.send_message(message=kwargs.get('message'))
-
-
 def load_model(run_name):
     k = []
     best_model_path_dict = dict()
