@@ -1,6 +1,5 @@
 import json
 from enum import Enum
-from Accuinsight.modeler.core.Run.RunInfo import RunInfo
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.core.Run.ParseRun import Parse_MLClassifier
 from Accuinsight.modeler.core.Run.ParseRun import Parse_DLRegression
@@ -15,23 +14,22 @@ class ModelType(Enum):
     ML_CLASSIFICATION = 4
 
 
-def run_parser(parser_type):
+def run_parser(parser_type, run_info_json):
     if parser_type is ModelType.DL_REGRESSION:
-        return Parse_DLRegression.parse_run_result()
+        return Parse_DLRegression.parse_run_result(run_info_json)
 
     if parser_type is ModelType.DL_CLASSIFICATION:
-        return Parse_DLClassification.parse_run_result()
+        return Parse_DLClassification.parse_run_result(run_info_json)
 
     if parser_type is ModelType.ML_REGRESSION:
-        return Parse_MLRegression.parse_run_result()
+        return Parse_MLRegression.parse_run_result(run_info_json)
 
     if parser_type is ModelType.ML_CLASSIFICATION:
-        return Parse_MLClassifier.parse_run_result()
+        return Parse_MLClassifier.parse_run_result(run_info_json)
 
 
-def get_parser_type():
+def get_parser_type(run_info_json):
     parser_type = None
-    run_info_json = RunInfo.get_current_run()
     run_result_path = run_info_json[LcConst.RUN_RESULT_PATH]
 
     # data_path = run_result_path[LcConst.RUN_MODEL_JSON_PATH]
