@@ -2,7 +2,6 @@ from collections.abc import Mapping
 from csv import DictReader
 import pandas as pd
 import json
-from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_current_run
 from Accuinsight.modeler.core.LcConst.LcConst import RUN_OBJ_CSV_PATH, RUN_BASE_PATH, RUN_RESULT_PATH, \
     RUN_MODEL_VISUAL_CSV_PATH, RUN_PREFIX_PATH, RUN_MODEL_JSON_PATH
 from Accuinsight.modeler.protos.life_cycle_pb2 import LcMetric, LcParam
@@ -11,17 +10,7 @@ from Accuinsight.modeler.protos.life_cycle_pb2 import LcMetric, LcParam
 # get metric path with run type
 
 
-def _get_current_run():
-    # {'run_name': 'keras',
-    #  'json_path': 'model-info-json/keras_nn-1.json',
-    #  'csv_path': 'for-visual-csv/keras_nn-history-1.csv'}
-
-    return get_current_run()
-
-
-def load_keras_parameter():
-    run_info_json = _get_current_run()
-
+def load_keras_parameter(run_info_json):
     run_result_path = run_info_json[RUN_RESULT_PATH]
     base_path = run_result_path[RUN_BASE_PATH]
     prefix_path = run_result_path[RUN_PREFIX_PATH]
@@ -34,20 +23,15 @@ def load_keras_parameter():
     return param_json_data
 
 
-def _read_csv_with_pandas():
-    run_info_json = _get_current_run()
+def _read_csv_with_pandas(run_info_json):
     csv_path = run_info_json[RUN_BASE_PATH] + 'results-keras/' + run_info_json[RUN_OBJ_CSV_PATH]
-    # csv_data = pd.read_csv(csv_path,
-    #                        sep=';', index_col='epoch')
 
     return pd.read_csv(csv_path, sep=';', index_col=0, squeeze=True, header=None).to_dict()
 
 
-def _read_csv_with_csv():
+def _read_csv_with_csv(run_info_json):
     column_dict = {}
 
-    run_info_json = _get_current_run()
-
     run_result_path = run_info_json[RUN_RESULT_PATH]
     base_path = run_result_path[RUN_BASE_PATH]
     prefix_path = run_result_path[RUN_PREFIX_PATH]
@@ -66,9 +50,9 @@ def _read_csv_with_csv():
     return column_dict
 
 
-def load_keras_metric():
-    # csv_data = _read_csv_with_pandas()
-    column_dict = _read_csv_with_csv()
+def load_keras_metric(run_info_json):
+    # csv_data = _read_csv_with_pandas(run_info_json)
+    column_dict = _read_csv_with_csv(run_info_json)
 
     result_dict = {'metrics': []}
     for key in column_dict:
@@ -78,8 +62,8 @@ def load_keras_metric():
     return result_dict
 
 
-def parse_keras_metric():
-    metric_data = load_keras_metric()
+def parse_keras_metric(run_info_json):
+    metric_data = load_keras_metric(run_info_json)
     metrics = metric_data['metrics']
 
     grpc_metrics = []
@@ -115,33 +99,11 @@ def _parse_optimizer_info(param_data):
     return grpc_params
 
 
-def parse_keras_parameter():
-    param_data = load_keras_parameter()
-
-    dummy_data = {
-        'model_description': 'keras test',
-        'logging_time': '2020-05-06 10:30:50',
-        'run_id': '9FCEF776-D830-4353-8961-144491DC03CC',
-        'model_type': 'keras_nn',
-        'optimizer_info': {
-            'RMSprop': {
-                'learning_rate': 9.999999747378752e-05,
-                'rho': 0.8999999761581421,
-                'decay': 0.0,
-                'epsilon': 1e-07
-            }
-        },
-        'time_delta': '0:00:14.912202'
-    }
-
-    return _parse_optimizer_info(param_data)
-
-
-def parse_run_result():
+def parse_run_result(run_info_json):
     result_dict = {'metrics': None, 'params': None, 'visual': None}
 
-    metric_data = parse_keras_metric()
-    parameter_data = parse_keras_parameter()
+    metric_data = parse_keras_metric(run_info_json)
+    parameter_data = _parse_optimizer_info(load_keras_parameter(run_info_json))
 
     result_dict['params'] = parameter_data
     result_dict['metrics'] = metric_data
